@@ -3,12 +3,11 @@
 extern crate good_web_game as ggez;
 
 use ggez::input::mouse::set_cursor_grabbed;
-use ggez::{event::EventHandler, Context, GameError, GameResult};
+use ggez::{event::EventHandler, Context, GameResult};
 
 fn main() -> GameResult<()> {
     ggez::start(
-        ggez::conf::Conf::default()
-            .cache(miniquad::conf::Cache::Tar(include_bytes!("resources.tar"))),
+        ggez::conf::Conf::default(),
         |context| {
             set_cursor_grabbed(context, true);
             Box::new(MousePos(0., 0.))
@@ -18,7 +17,7 @@ fn main() -> GameResult<()> {
 
 struct MousePos(f32, f32);
 
-impl EventHandler<GameError> for MousePos {
+impl EventHandler for MousePos {
     fn update(&mut self, ctx: &mut Context) -> GameResult<()> {
         println!("UPDATE: delta: {:?}", ggez::input::mouse::delta(ctx));
         Ok(())
