@@ -111,7 +111,7 @@ fn build_textured_triangle(ctx: &mut Context) -> GameResult<graphics::Mesh> {
     mb.build(ctx)
 }
 
-impl event::EventHandler<ggez::GameError> for MainState {
+impl event::EventHandler for MainState {
     fn update(&mut self, ctx: &mut Context) -> GameResult {
         const DESIRED_FPS: u32 = 60;
 
@@ -221,9 +221,9 @@ pub fn main() -> GameResult {
 
     ggez::start(
         ggez::conf::Conf::default()
-            .cache(miniquad::conf::Cache::Tar(include_bytes!("resources.tar")))
-            .physical_root_dir(Some(resource_dir))
-            .sample_count(16),
+            .cache(Some(include_bytes!("resources.tar")))
+            .physical_root_dir(Some(resource_dir)),
+            //.sample_count(16),
         |mut context| Box::new(MainState::new(&mut context).unwrap()),
     )
 }
