@@ -497,7 +497,7 @@ fn draw_actor(
 /// ggez with callbacks for updating and drawing our game, as well as
 /// handling input events.
 /// **********************************************************************
-impl EventHandler<ggez::GameError> for MainState {
+impl EventHandler for MainState {
     fn update(&mut self, ctx: &mut Context) -> GameResult {
         const DESIRED_FPS: u32 = 60;
 
@@ -630,6 +630,23 @@ impl EventHandler<ggez::GameError> for MainState {
         Ok(())
     }
 
+    fn resize_event(&mut self, context: &mut Context, w: f32, h: f32) {
+        self.screen_width = w;
+        self.screen_height = h;
+        let coordinates = graphics::Rect::new(0., 0.0, w, h);
+
+        graphics::set_screen_coordinates(context, coordinates).expect("Can't resize the window");
+    }
+
+    fn mouse_button_up_event(&mut self, _ctx: &mut Context, button: MouseButton, _x: f32, _y: f32) {
+        if let MouseButton::Left = button {
+            // stop shooting and accelerating
+            self.input.yaxis = 0.0;
+            self.input.xaxis = 0.0;
+            self.input.fire = false;
+        }
+    }
+
     // Handle key events.  These just map keyboard events
     // and alter our input state appropriately.
     fn key_down_event(
@@ -676,23 +693,6 @@ impl EventHandler<ggez::GameError> for MainState {
             _ => (), // Do nothing
         }
     }
-
-    fn mouse_button_up_event(&mut self, _ctx: &mut Context, button: MouseButton, _x: f32, _y: f32) {
-        if let MouseButton::Left = button {
-            // stop shooting and accelerating
-            self.input.yaxis = 0.0;
-            self.input.xaxis = 0.0;
-            self.input.fire = false;
-        }
-    }
-
-    fn resize_event(&mut self, context: &mut Context, w: f32, h: f32) {
-        self.screen_width = w;
-        self.screen_height = h;
-        let coordinates = graphics::Rect::new(0., 0.0, w, h);
-
-        graphics::set_screen_coordinates(context, coordinates).expect("Can't resize the window");
-    }
 }
 
 /// **********************************************************************
@@ -706,7 +706,7 @@ pub fn main() -> GameResult {
 
     ggez::start(
         ggez::conf::Conf::default()
-            .cache(miniquad::conf::Cache::Tar(include_bytes!("resources.tar"))),
+            .cache(Some(include_bytes!("resources.tar"))),
         |mut context| Box::new(MainState::new(&mut context).unwrap()),
     )
 }
