@@ -4,7 +4,6 @@ pub use glyph_brush::{ab_glyph::PxScale, GlyphBrush, HorizontalAlign as Align};
 use std::borrow::Cow;
 use std::cell::RefCell;
 use std::convert::TryFrom;
-use std::f32;
 use std::fmt;
 use std::io::Read;
 use std::path;
@@ -76,8 +75,8 @@ impl TextFragment {
     }
 
     /// Set fragment's color, overrides text's color.
-    pub fn color(mut self, color: Color) -> TextFragment {
-        self.color = Some(color);
+    pub fn color<C: Into<Color>>(mut self, color: C) -> TextFragment {
+        self.color = Some(color.into());
         self
     }
 
@@ -87,9 +86,9 @@ impl TextFragment {
         self
     }
 
-    /// Set fragment's scale, overrides text's scale.
-    pub fn scale(mut self, scale: PxScale) -> TextFragment {
-        self.scale = Some(scale);
+    /// Set fragment's scale, overrides text's scale. Default is 16.0
+    pub fn scale<S: Into<PxScale>>(mut self, scale: S) -> TextFragment {
+        self.scale = Some(scale.into());
         self
     }
 }
@@ -132,7 +131,7 @@ where
 
 /// Cached font metrics that we can keep attached to a `Text`
 /// so we don't have to keep recalculating them.
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, Default)]
 struct CachedMetrics {
     string: Option<String>,
     width: Option<f32>,
@@ -140,17 +139,6 @@ struct CachedMetrics {
     glyph_positions: Vec<mint::Point2<f32>>,
 }
 
-impl Default for CachedMetrics {
-    fn default() -> CachedMetrics {
-        CachedMetrics {
-            string: None,
-            width: None,
-            height: None,
-            glyph_positions: Vec::new(),
-        }
-    }
-}
-
 /// Drawable text object.  Essentially a list of [`TextFragment`](struct.TextFragment.html)'s
 /// and some cached size information.
 ///
